==> deepin-deb-installer_1.2.4.orig.tar.gz: deepin-deb-installer-1.2.4/translations/deepin-deb-installer_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Instalar en bloque</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Fallo ao instalar, verifica a conexión de rede</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Fallo ao instalar, verifica as actualizacións no Centro de Control</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Fallo ao instalar, sen espazo abondo no disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Fallo ao instalar</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>A arquitectura do paquete non coincide</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Seleccionar ficheiro</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Amosar detalles</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Fallo</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Amosar detalles</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Instalado con éxito</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalado con éxito</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Outra versión instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Fallo ao desinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Mesma versión instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Amosar paquetes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Tes a certeza de querer desinstalar %1?
Eliminaranse tódalas dependencias</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.3.0.orig.tar.gz: deepin-deb-installer-1.3.0/translations/deepin-deb-installer_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Instalar en bloque</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Fallo ao instalar, verifica a conexión de rede</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Fallo ao instalar, verifica as actualizacións no Centro de Control</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Fallo ao instalar, sen espazo abondo no disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Fallo ao instalar</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>A arquitectura do paquete non coincide</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Arrastrar ficheiros aquí</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Seleccionar ficheiro</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Amosar detalles</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Fallo</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Mesma versión instalada</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Outra versión instalada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Amosar detalles</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Instalado con éxito</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalado con éxito</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Outra versión instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Fallo ao desinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>Mesma versión instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Amosar paquetes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Tes a certeza de querer desinstalar %1?
Eliminaranse tódalas dependencias</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Xestor de paquetes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>O xestor de paquetes empregase para axudar aos usuarios a instalar e eliminar software local, tamén soporta a instalación en bloque.</translation>
    </message>
</context>
</TS>
